OC.L10N.register(
    "mail",
    {
    "Mail" : "E-pošta",
    "Name" : "Ime",
    "Password" : "Lozinka",
    "None" : "Ništa",
    "SMTP Password" : "SMPT Lozinka",
    "Save" : "Spremi",
    "Send" : "Pošalji",
    "Select" : "Select",
    "Delete" : "Obriši",
    "Important" : "Važno",
    "Favorites" : "Favoriti",
    "Other" : "Ostali",
    "Settings" : "Podešavanje",
    "Quota" : "Kvota",
    "Add folder" : "Add folder",
    "Cancel" : "Otkaži",
    "Delete folder" : "Izbriši fasciklu",
    "User" : "User",
    "Port" : "Priključak",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Search" : "Search",
    "All" : "Sve"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
